@@ -86,6 +86,7 @@ struct _PhotosEmbed
   PhotosModeController *mode_cntrlr;
   PhotosSearchController *srch_cntrlr;
   PhotosTrackerController *trk_ovrvw_cntrlr;
+  gboolean search_changed;
   guint load_show_id;
 };
 
@@ -190,11 +191,13 @@ photos_embed_restore_search (PhotosEmbed *self)
   if (!self->search_state.saved)
     return;
 
+  photos_embed_block_search_changed (self);
   photos_base_manager_set_active_object (self->src_mngr, self->search_state.source);
   photos_base_manager_set_active_object (self->srch_mngr, self->search_state.search_type);
   photos_search_controller_set_string (self->srch_cntrlr, self->search_state.str);
-  self->search_state.saved = FALSE;
+  photos_embed_unblock_search_changed (self);
 
+  self->search_state.saved = FALSE;
   photos_embed_clear_search (self);
 
   state = g_variant_new ("b", TRUE);
@@ -217,8 +220,10 @@ photos_embed_save_search (PhotosEmbed *self)
   self->search_state.str = g_strdup (photos_search_controller_get_string (self->srch_cntrlr));
   self->search_state.saved = TRUE;
 
+  photos_embed_block_search_changed (self);
   state = g_variant_new ("b", FALSE);
   g_action_change_state (self->search_action, state);
+  photos_embed_unblock_search_changed (self);
 }
 
 
@@ -345,27 +350,9 @@ photos_embed_active_collection_changed (PhotosBaseManager *manager, PhotosBaseIt
     return;
 
   if (collection == NULL)
-    {
-      photos_embed_restore_search (self);
-    }
+    photos_embed_restore_search (self);
   else
-    {
-      PhotosSearchType *search_type;
-      const gchar *str;
-      const gchar *id;
-
-      photos_embed_save_search (self);
-
-      search_type = PHOTOS_SEARCH_TYPE (photos_base_manager_get_active_object (self->srch_mngr));
-      str = photos_search_controller_get_string (self->srch_cntrlr);
-      id = photos_filterable_get_id (PHOTOS_FILTERABLE (search_type));
-
-      if (g_strcmp0 (str, "") != 0 || g_strcmp0 (id, "all") != 0)
-        {
-          photos_base_manager_set_active_object_by_id (self->srch_mngr, "all");
-          photos_search_controller_set_string (self->srch_cntrlr, "");
-        }
-    }
+    photos_embed_save_search (self);
 }
 
 
@@ -378,10 +365,17 @@ photos_embed_fullscreen_changed (PhotosModeController *mode_cntrlr, gboolean ful
 static void
 photos_embed_notify_visible_child (PhotosEmbed *self)
 {
+  GdkEvent *event = NULL;
   GtkWidget *visible_child;
-  GVariant *state;
   PhotosWindowMode mode = PHOTOS_WINDOW_MODE_NONE;
 
+  event = gtk_get_current_event ();
+  if (event == NULL)
+    goto out;
+
+  if (event->type != GDK_BUTTON_RELEASE && event->type != GDK_TOUCH_END)
+    goto out;
+
   visible_child = gtk_stack_get_visible_child (GTK_STACK (self->stack));
   if (visible_child == self->overview)
     mode = PHOTOS_WINDOW_MODE_OVERVIEW;
@@ -391,17 +385,12 @@ photos_embed_notify_visible_child (PhotosEmbed *self)
     mode = PHOTOS_WINDOW_MODE_FAVORITES;
 
   if (mode == PHOTOS_WINDOW_MODE_NONE)
-    return;
-
-  if (!photos_main_toolbar_is_focus (PHOTOS_MAIN_TOOLBAR (self->toolbar)))
-    {
-      photos_embed_block_search_changed (self);
-      state = g_variant_new ("b", FALSE);
-      g_action_change_state (self->search_action, state);
-      photos_embed_unblock_search_changed (self);
-    }
+    goto out;
 
   photos_mode_controller_set_window_mode (self->mode_cntrlr, mode);
+
+ out:
+  g_clear_pointer (&event, (GDestroyNotify) gdk_event_free);
 }
 
 
@@ -471,7 +460,6 @@ static void
 photos_embed_search_changed (PhotosEmbed *self)
 {
   GObject *object;
-  PhotosWindowMode mode;
   const gchar *search_type_id;
   const gchar *source_id;
   const gchar *str;
@@ -480,18 +468,9 @@ photos_embed_search_changed (PhotosEmbed *self)
    * the search mode, and when all constraints have been lifted we
    * want to go back to the previous mode which can be either
    * collections, favorites or overview.
-   *
-   * However there are some exceptions, which are taken care of
-   * elsewhere:
-   *  - when moving from search to preview or collection view
-   *  - when in preview
    */
-  object = photos_base_manager_get_active_object (self->item_mngr);
-  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
-  if (mode == PHOTOS_WINDOW_MODE_SEARCH && object != NULL)
-    return;
-  if (mode == PHOTOS_WINDOW_MODE_PREVIEW)
-    return;
+
+  self->search_changed = TRUE;
 
   object = photos_base_manager_get_active_object (self->src_mngr);
   source_id = photos_filterable_get_id (PHOTOS_FILTERABLE (object));
@@ -507,6 +486,8 @@ photos_embed_search_changed (PhotosEmbed *self)
     photos_mode_controller_go_back (self->mode_cntrlr);
   else
     photos_mode_controller_set_window_mode (self->mode_cntrlr, PHOTOS_WINDOW_MODE_SEARCH);
+
+  self->search_changed = FALSE;
 }
 
 
@@ -583,6 +564,33 @@ photos_embed_window_mode_changed (PhotosModeController *mode_cntrlr,
 {
   PhotosEmbed *self = PHOTOS_EMBED (user_data);
 
+  switch (mode)
+    {
+    case PHOTOS_WINDOW_MODE_COLLECTIONS:
+    case PHOTOS_WINDOW_MODE_FAVORITES:
+    case PHOTOS_WINDOW_MODE_OVERVIEW:
+      if (!self->search_changed)
+        {
+          GVariant *state;
+
+          photos_embed_block_search_changed (self);
+          state = g_variant_new ("b", FALSE);
+          g_action_change_state (self->search_action, state);
+          photos_embed_unblock_search_changed (self);
+        }
+      break;
+
+    case PHOTOS_WINDOW_MODE_EDIT:
+    case PHOTOS_WINDOW_MODE_PREVIEW:
+    case PHOTOS_WINDOW_MODE_SEARCH:
+      break;
+
+    case PHOTOS_WINDOW_MODE_NONE:
+    default:
+      g_assert_not_reached ();
+      break;
+    }
+
   photos_main_toolbar_reset_toolbar_mode (PHOTOS_MAIN_TOOLBAR (self->toolbar));
 
   switch (mode)
